@@ -323,8 +323,8 @@ class CertClass (qt.QWidget):
                                         (OpenSSL.SSL.FILETYPE_PEM, ca_root)
                 Issuer = certobj.get_issuer().get_components()
                 for item in Issuer:
-                    if item[0] == 'CN':
-                        filename = item[1]
+                    if item[0] == b'CN':
+                        filename = item[1].decode("UTF-8")
 
                 fc = open(root_cert_md5,"a")
                 fc.write('%s %s\n' %(md5sum, filename))
