@@ -14,13 +14,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 
 from .more import ButtonMenu, FlowLayout, get_sid, ClientServiceThread, \
                  get_view_params, show_msg, client_list_methods, get_system_rgb, \
                  get_icon, dpivalue
 
+DEBUG_LEVEL = 99999
+
+def debug(level, *args):
+    if level <= DEBUG_LEVEL:
+        for s in args:
+            print(s, end=' ')
+        print()
+
 class DisplayMethod(qt.QWidget):
     def __init__(self, parent, ClientObj):
         super().__init__(parent)
@@ -52,6 +59,7 @@ class DisplayMethod(qt.QWidget):
         if type(results) == int:
 #            self.layout.addWidget(LabelWordWrap(_('No Methods!'),self))
             self.setLayout(self.layout)
+            debug(11, "DEBUG DisplayMethod")
             self.show()
             return 1
         for num in range (0, len(results)):
@@ -120,8 +128,8 @@ class DisplayMethod(qt.QWidget):
 
             if group not in self.layout_dict:
                 self.layout_dict[group] = FlowLayout(self.groupbox_dict[group])
-            view_name_sort = list(filter(lambda x: guiMethods[group].index(x) % 3 \
-                                    == 1, guiMethods[group]))
+            view_name_sort = [x for x in guiMethods[group] 
+                if guiMethods[group].index(x) % 3 == 1]
             view_name_sort.sort()
             guiMethods_sort = []
             for sort_name in view_name_sort:
@@ -322,6 +330,7 @@ class DisplayMethod(qt.QWidget):
             self.ClientObj.MainWidget.main_frame.setWidgetResizable(True)
 
             self.ClientObj.MainWidget.left_frame.update()
+            debug(11, "DEBUG groupActivated")
             self.ClientObj.MainWidget.left_frame.show()
 
             try:
