@@ -14,8 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 import urllib.request as urllib2
 from calculate.lib.utils.tools import Locker
 
